@@ -870,7 +870,10 @@ QPoint KateViewInternal::cursorCoordinates()
 void KateViewInternal::updateMicroFocusHint()
 {
     int line = displayViewLine(displayCursor, true);
-    if (line == -1)
+    /* Check for hasFocus() to avoid crashes in QXIMInputContext as in bug #131266.
+    This is only a workaround until somebody can find the real reason of the crash
+    (probably it's in Qt). */
+    if (line == -1 || !hasFocus()) 
         return;
 
     KateRenderer *renderer = m_view->renderer();
@@ -1258,20 +1261,17 @@ void KateViewInternal::end( bool sel )
     m_view->m_codeCompletion->handleKey(&e);
     return;
   }
-  
-  // FIXME: Both "smart end" and "smart home" use the current range's last/first character
-  //        when jumping to the "absolute" extreme. For 4.0 and 3.5.5 (kling)
-  bool alreadyAtEndOfLine = false;
 
-  if (m_view->dynWordWrap() && currentRange().wrap) {
+  KateLineRange range = currentRange();
+
+  if (m_view->dynWordWrap() && range.wrap) {
     // Allow us to go to the real end if we're already at the end of the view line
-    if (cursor.col() < currentRange().endCol - 1) {
-      KateTextCursor c(cursor.line(), currentRange().endCol - 1);
+    if (cursor.col() < range.endCol - 1) {
+      KateTextCursor c(cursor.line(), range.endCol - 1);
       updateSelection( c, sel );
       updateCursor( c );
       return;
     }
-    alreadyAtEndOfLine = true;
   }
 
   if( !(m_doc->configFlags() & KateDocument::cfSmartHome) ) {
@@ -1286,23 +1286,16 @@ void KateViewInternal::end( bool sel )
 
   // "Smart End", as requested in bugs #78258 and #106970
   KateTextCursor c = cursor;
-  int lc = l->lastChar();
 
-  // Apparently, currentRange().endCol differs by 1 depending on m_view->dynWordWrap()...
-  int endOfLine = currentRange().endCol - (m_view->dynWordWrap() ? 1 : 0);
-
-  if (lc < 0 || c.col() == (lc + 1)) {
-    if (alreadyAtEndOfLine) {
-      moveEdge(right, sel);
-      return;
-    }
-    c.setCol(endOfLine);
+  // If the cursor is already the real end, jump to last non-space character.
+  // Otherwise, go to the real end ... obviously.
+  if (c.col() == m_doc->lineLength(c.line())) {
+    c.setCol(l->lastChar() + 1);
+    updateSelection(c, sel);
+    updateCursor(c, true);
   } else {
-    c.setCol(lc + 1);
+    moveEdge(right, sel);
   }
-
-  updateSelection( c, sel );
-  updateCursor( c, true );
 }
 
 KateLineRange KateViewInternal::range(int realLine, const KateLineRange* previous)
@@ -2682,8 +2675,6 @@ void KateViewInternal::mousePressEvent( QMouseEvent* e )
           selStartCached = m_view->selectStart;
           selEndCached = m_view->selectEnd;
 
-          cursor.setCol(0);
-          updateCursor( cursor, true );
           e->accept ();
           return;
         }
@@ -2746,6 +2737,11 @@ void KateViewInternal::mouseDoubleClickEvent(QMouseEvent *e)
         selectAnchor = KateTextCursor (m_view->selEndLine(), m_view->selEndCol());
         selStartCached = m_view->selectStart;
         selEndCached = m_view->selectEnd;
+
+        // if we didn't actually select anything, restore the selection mode
+        // -- see bug #131369 (kling)
+        if (!m_view->hasSelection())
+          m_selectionMode = Default;
       }
 
       // Move cursor to end of selected word
@@ -2755,9 +2751,6 @@ void KateViewInternal::mouseDoubleClickEvent(QMouseEvent *e)
         m_view->copy();
         QApplication::clipboard()->setSelectionMode( false );
 
-        cursor.setPos(m_view->selectEnd);
-        updateCursor( cursor, true );
-
         selStartCached = m_view->selectStart;
         selEndCached = m_view->selectEnd;
       }
@@ -3013,7 +3006,7 @@ void KateViewInternal::focusInEvent (QFocusEvent *)
 
 void KateViewInternal::focusOutEvent (QFocusEvent *)
 {
-  if( ! m_view->m_codeCompletion->codeCompletionVisible() )
+  if( m_view->renderer() && ! m_view->m_codeCompletion->codeCompletionVisible() )
   {
     m_cursorTimer.stop();
 
