@@ -161,9 +161,11 @@ KStandardDirs *KInstance::dirs() const
     DEBUG_CHECK_ALIVE
     if( _dirs == 0 ) {
 	_dirs = new KStandardDirs( );
-        if (_config)
+        if (_config) {
             if (_dirs->addCustomized(_config))
                 _config->reparseConfiguration();
+	} else
+            config(); // trigger adding of possible customized dirs
     }
 
     return _dirs;
@@ -269,7 +271,8 @@ KMimeSourceFactory* KInstance::mimeSourceFactory () const
   DEBUG_CHECK_ALIVE
   if (!d->mimeSourceFactory)
   {
-    d->mimeSourceFactory = new KMimeSourceFactory(iconLoader());
+    d->mimeSourceFactory = new KMimeSourceFactory(_iconLoader);
+    d->mimeSourceFactory->setInstance(const_cast<KInstance *>(this));
   }
 
   return d->mimeSourceFactory;
