@@ -747,7 +747,7 @@ VFolderMenu::pushDocInfoParent(const QString &basePath, const QString &baseDir)
 
    while( !result.isEmpty() && (result[0] != basePath))
       result.remove(result.begin());
-      
+
    if (result.count() <= 1)
    {
       m_docInfo.path = QString::null; // No parent found
@@ -772,8 +772,28 @@ VFolderMenu::locateMenuFile(const QString &fileName)
       return QString::null;
    }
 
-   QString baseName = QDir::cleanDirPath(m_docInfo.baseDir + fileName);
-   QString result = locate("xdgconf-menu", baseName);
+   QString result;
+
+   QString xdgMenuPrefix = QString::fromLocal8Bit(getenv("XDG_MENU_PREFIX"));
+   if (!xdgMenuPrefix.isEmpty())
+   {
+      QFileInfo fileInfo(fileName);
+
+      QString fileNameOnly = fileInfo.fileName();
+      if (!fileNameOnly.startsWith(xdgMenuPrefix))
+         fileNameOnly = xdgMenuPrefix + fileNameOnly;
+
+      QString baseName = QDir::cleanDirPath(m_docInfo.baseDir +
+                                            fileInfo.dirPath() + "/" +
+                                            fileNameOnly);
+      result = locate("xdgconf-menu", baseName);
+   }
+
+   if (result.isEmpty())
+   {
+       QString baseName = QDir::cleanDirPath(m_docInfo.baseDir + fileName);
+       result = locate("xdgconf-menu", baseName);
+   }
 
    return result;
 }
@@ -847,11 +867,15 @@ VFolderMenu::processCondition(QDomElement &domElem, QDict<KService> *items)
    if (domElem.tagName() == "And")
    {
       QDomNode n = domElem.firstChild();
-      if (!n.isNull())
+      // Look for the first child element
+      while (!n.isNull()) // loop in case of comments
       {
          QDomElement e = n.toElement();
-         processCondition(e, items);
          n = n.nextSibling();
+         if ( !e.isNull() ) {
+             processCondition(e, items);
+             break; // we only want the first one
+         }
       }
 
       QDict<KService> andItems;
@@ -881,19 +905,25 @@ VFolderMenu::processCondition(QDomElement &domElem, QDict<KService> *items)
    else if (domElem.tagName() == "Or")
    {
       QDomNode n = domElem.firstChild();
-      if (!n.isNull())
+      // Look for the first child element
+      while (!n.isNull()) // loop in case of comments
       {
          QDomElement e = n.toElement();
-         processCondition(e, items);
          n = n.nextSibling();
+         if ( !e.isNull() ) {
+             processCondition(e, items);
+             break; // we only want the first one
+         }
       }
 
       QDict<KService> orItems;
       while( !n.isNull() ) {
          QDomElement e = n.toElement();
-         orItems.clear();
-         processCondition(e, &orItems);
-         includeItems(items, &orItems);
+         if ( !e.isNull() ) {
+             orItems.clear();
+             processCondition(e, &orItems);
+             includeItems(items, &orItems);
+         }
          n = n.nextSibling();
       }
    }
@@ -910,9 +940,11 @@ VFolderMenu::processCondition(QDomElement &domElem, QDict<KService> *items)
       QDomNode n = domElem.firstChild();
       while( !n.isNull() ) {
          QDomElement e = n.toElement();
-         notItems.clear();
-         processCondition(e, &notItems);
-         excludeItems(items, &notItems);
+         if ( !e.isNull() ) {
+             notItems.clear();
+             processCondition(e, &notItems);
+             excludeItems(items, &notItems);
+         }
          n = n.nextSibling();
       }
    }
