@@ -329,6 +329,10 @@ bool IppRequest::doFileRequest(const QString& res, const QString& filename)
 		dumpRequest(request_, true);
 	}
 
+	/* No printers found */
+	if ( request_ && request_->request.status.status_code == 0x406 )
+		return true;
+
 	if (!request_ || request_->state == IPP_ERROR || (request_->request.status.status_code & 0x0F00))
 		return false;
 
@@ -511,6 +515,11 @@ void IppRequest::setMap(const QMap<QString,QString>& opts)
 	cupsFreeOptions(n, options);
 
 	// find an remove that annoying "document-format" attribute
+#if CUPS_VERSION_MAJOR == 1 && CUPS_VERSION_MINOR >= 2
+    ipp_attribute_t *attr = ippFindAttribute(request_, "document-format", IPP_TAG_NAME);
+    ippDeleteAttribute(request_, attr);
+#else
+	// (can't use IppDeleteAttribute as older cups doesn't have that)
 	ipp_attribute_t	*attr = request_->attrs;
 	while (attr)
 	{
@@ -523,4 +532,5 @@ void IppRequest::setMap(const QMap<QString,QString>& opts)
 		}
 		attr = attr->next;
 	}
+#endif
 }
