@@ -1,6 +1,6 @@
 /*
  *  This file is part of the KDE libraries
- *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
+ *  Copyright (c) 2001 Michael Goffioul <kdeprint@swing.be>
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -13,26 +13,30 @@
  *
  *  You should have received a copy of the GNU Library General Public License
  *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- *  Boston, MA 02111-1307, USA.
+ *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ *  Boston, MA 02110-1301, USA.
  **/
 
 #include "kxmlcommanddlg.h"
 #include "driver.h"
 #include "kxmlcommand.h"
 
-#include <qheader.h>
 #include <qlayout.h>
+#include <qheader.h>
 #include <qlabel.h>
 #include <qlineedit.h>
 #include <qcombobox.h>
 #include <qgroupbox.h>
 #include <qwidgetstack.h>
+#include <qtoolbutton.h>
 #include <kpushbutton.h>
 #include <qtooltip.h>
+#include <qcheckbox.h>
 #include <ktextedit.h>
-#include <qheader.h>
 #include <qregexp.h>
+#include <qwhatsthis.h>
+#include <qapplication.h>
+
 #include <klistview.h>
 #include <klocale.h>
 #include <kiconloader.h>
@@ -84,18 +88,18 @@ KXmlCommandAdvancedDlg::KXmlCommandAdvancedDlg(QWidget *parent, const char *name
 	m_view->addColumn("");
 	m_view->header()->hide();
 	m_view->setSorting(-1);
-	m_apply = new QPushButton(this);
-	m_apply->setPixmap(SmallIcon("back"));
-	m_addgrp = new QPushButton(this);
-	m_addgrp->setPixmap(SmallIcon("folder"));
-	m_addopt = new QPushButton(this);
-	m_addopt->setPixmap(SmallIcon("document"));
-	m_delopt = new QPushButton(this);
-	m_delopt->setPixmap(SmallIcon("editdelete"));
-	m_up = new QPushButton(this);
-	m_up->setPixmap(SmallIcon("up"));
-	m_down = new QPushButton(this);
-	m_down->setPixmap(SmallIcon("down"));
+	m_apply = new QToolButton(this);
+	m_apply->setIconSet( QApplication::reverseLayout()? SmallIconSet( "forward" ) : SmallIconSet("back"));
+	m_addgrp = new QToolButton(this);
+	m_addgrp->setIconSet(SmallIconSet("folder"));
+	m_addopt = new QToolButton(this);
+	m_addopt->setIconSet(SmallIconSet("document"));
+	m_delopt = new QToolButton(this);
+	m_delopt->setIconSet(SmallIconSet("editdelete"));
+	m_up = new QToolButton(this);
+	m_up->setIconSet(SmallIconSet("up"));
+	m_down = new QToolButton(this);
+	m_down->setIconSet(SmallIconSet("down"));
 	m_dummy = new QWidget(this);
 	m_desc = new QLineEdit(m_dummy);
 	m_name = new QLineEdit(m_dummy);
@@ -119,6 +123,7 @@ KXmlCommandAdvancedDlg::KXmlCommandAdvancedDlg(QWidget *parent, const char *name
 	m_typelab->setBuddy(m_type);
 	m_defaultlab->setBuddy(m_default);
 	m_commandlab->setBuddy(m_command);
+	m_persistent = new QCheckBox( i18n( "&Persistent option" ), m_dummy );
 
 	QGroupBox	*gb = new QGroupBox(0, Qt::Horizontal, i18n("Va&lues"), m_dummy);
 	m_stack = new QWidgetStack(gb);
@@ -138,19 +143,19 @@ KXmlCommandAdvancedDlg::KXmlCommandAdvancedDlg(QWidget *parent, const char *name
 	m_values->setAllColumnsShowFocus(true);
 	m_values->setSorting(-1);
 	m_values->setMaximumHeight(110);
-	m_addval = new QPushButton(w2);
-	m_addval->setPixmap(SmallIcon("editcopy"));
-	m_delval = new QPushButton(w2);
-	m_delval->setPixmap(SmallIcon("editdelete"));
-	QToolTip::add(m_addval, i18n("Add Value"));
-	QToolTip::add(m_delval, i18n("Delete Value"));
+	m_addval = new QToolButton(w2);
+	m_addval->setIconSet(SmallIconSet("editcopy"));
+	m_delval = new QToolButton(w2);
+	m_delval->setIconSet(SmallIconSet("editdelete"));
+	QToolTip::add(m_addval, i18n("Add value"));
+	QToolTip::add(m_delval, i18n("Delete value"));
 
-	QToolTip::add(m_apply, i18n("Apply Changes"));
-	QToolTip::add(m_addgrp, i18n("Add Group"));
-	QToolTip::add(m_addopt, i18n("Add Option"));
-	QToolTip::add(m_delopt, i18n("Delete Item"));
-	QToolTip::add(m_up, i18n("Move Up"));
-	QToolTip::add(m_down, i18n("Move Down"));
+	QToolTip::add(m_apply, i18n("Apply changes"));
+	QToolTip::add(m_addgrp, i18n("Add group"));
+	QToolTip::add(m_addopt, i18n("Add option"));
+	QToolTip::add(m_delopt, i18n("Delete item"));
+	QToolTip::add(m_up, i18n("Move up"));
+	QToolTip::add(m_down, i18n("Move down"));
 
 	KSeparator	*sep1 = new KSeparator(KSeparator::HLine, m_dummy);
 
@@ -169,14 +174,14 @@ KXmlCommandAdvancedDlg::KXmlCommandAdvancedDlg(QWidget *parent, const char *name
 	m_comment->setTextFormat( Qt::PlainText );
 	QLabel *m_commentlab = new QLabel( i18n( "Comment:" ), this );
 
-	QVBoxLayout	*l2 = new QVBoxLayout(this, 10, 10);
-	QHBoxLayout	*l3 = new QHBoxLayout(0, 0, 10);
+	QVBoxLayout	*l2 = new QVBoxLayout(this, 0, KDialog::spacingHint());
+	QHBoxLayout	*l3 = new QHBoxLayout(0, 0, KDialog::spacingHint());
 	QVBoxLayout	*l7 = new QVBoxLayout(0, 0, 0);
 	l2->addLayout(l3, 0);
 	l3->addWidget(m_commandlab);
 	l3->addWidget(m_command);
-	QHBoxLayout	*l0 = new QHBoxLayout(0, 0, 10);
-	QGridLayout	*l10 = new QGridLayout(0, 2, 2, 0, 10);
+	QHBoxLayout	*l0 = new QHBoxLayout(0, 0, KDialog::spacingHint());
+	QGridLayout	*l10 = new QGridLayout(0, 2, 2, 0, KDialog::spacingHint());
 	l2->addLayout(l0, 1);
 	l0->addLayout(l10);
 	l10->addMultiCellWidget(m_view, 0, 0, 0, 1);
@@ -194,7 +199,7 @@ KXmlCommandAdvancedDlg::KXmlCommandAdvancedDlg(QWidget *parent, const char *name
 	l7->addWidget(m_down);
 	l7->addStretch(1);
 	l0->addWidget(m_dummy, 1);
-	QGridLayout	*l1 = new QGridLayout(m_dummy, 8, 2, 0, 10);
+	QGridLayout	*l1 = new QGridLayout(m_dummy, 9, 2, 0, KDialog::spacingHint());
 	l1->addWidget(m_desclab, 0, 0, Qt::AlignRight|Qt::AlignVCenter);
 	l1->addWidget(m_desc, 0, 1);
 	l1->addMultiCellWidget(sep1, 1, 1, 0, 1);
@@ -206,25 +211,28 @@ KXmlCommandAdvancedDlg::KXmlCommandAdvancedDlg(QWidget *parent, const char *name
 	l1->addWidget(m_format, 4, 1);
 	l1->addWidget(m_defaultlab, 5, 0, Qt::AlignRight|Qt::AlignVCenter);
 	l1->addWidget(m_default, 5, 1);
-	l1->addMultiCellWidget(gb, 6, 6, 0, 1);
-	l1->setRowStretch(7, 1);
+	l1->addWidget( m_persistent, 6, 1 );
+	l1->addMultiCellWidget(gb, 7, 7, 0, 1);
+	l1->setRowStretch(8, 1);
 
-	QHBoxLayout	*l4 = new QHBoxLayout(w2, 0, 5);
+	QHBoxLayout	*l4 = new QHBoxLayout(w2, 0, KDialog::spacingHint());
 	l4->addWidget(m_values);
 	QVBoxLayout	*l6 = new QVBoxLayout(0, 0, 0);
 	l4->addLayout(l6);
 	l6->addWidget(m_addval);
 	l6->addWidget(m_delval);
 	l6->addStretch(1);
-	QGridLayout	*l5 = new QGridLayout(w1, 3, 2, 0, 10);
+	QGridLayout	*l5 = new QGridLayout(w1, 3, 2, 0, KDialog::spacingHint());
 	l5->setRowStretch(2, 1);
 	l5->addWidget(m_editlab1, 0, 0, Qt::AlignRight|Qt::AlignVCenter);
 	l5->addWidget(m_editlab2, 1, 0, Qt::AlignRight|Qt::AlignVCenter);
 	l5->addWidget(m_edit1, 0, 1);
 	l5->addWidget(m_edit2, 1, 1);
 
-	QGridLayout	*l8 = new QGridLayout(gb_input->layout(), 2, 2, 5);
-	QGridLayout	*l9 = new QGridLayout(gb_output->layout(), 2, 2, 5);
+	QGridLayout	*l8 = new QGridLayout(gb_input->layout(), 2, 2,
+		KDialog::spacingHint());
+	QGridLayout	*l9 = new QGridLayout(gb_output->layout(), 2, 2,
+		KDialog::spacingHint());
 	l8->addWidget(m_inputfilelab, 0, 0);
 	l8->addWidget(m_inputpipelab, 1, 0);
 	l8->addWidget(m_inputfile, 0, 1);
@@ -265,9 +273,73 @@ KXmlCommandAdvancedDlg::KXmlCommandAdvancedDlg(QWidget *parent, const char *name
 	connect(m_type, SIGNAL(activated(int)), SLOT(slotChanged()));
 	connect(m_addval, SIGNAL(clicked()), SLOT(slotChanged()));
 	connect(m_delval, SIGNAL(clicked()), SLOT(slotChanged()));
+	connect( m_persistent, SIGNAL( toggled(bool) ), SLOT( slotChanged() ) );
 	m_dummy->setEnabled(false);
 	viewItem(0);
 
+	/**
+	 * Add some short help for the normal (non expert) user
+	 */
+	QWhatsThis::add( m_name, i18n(
+				"An identification string. Use only alphanumeric characters except spaces. "
+				"The string <b>__root__</b> is reserved for internal use." ) );
+	QWhatsThis::add( m_namelab, QWhatsThis::textFor( m_name ) );
+	QWhatsThis::add( m_desc, i18n(
+				"A description string. This string is shown in the interface, and should "
+				"be explicit enough about the role of the corresponding option." ) );
+	QWhatsThis::add( m_desclab, QWhatsThis::textFor( m_desc ) );
+	QWhatsThis::add( m_type, i18n(
+				"The type of the option. This determines how the option is presented "
+				"graphically to the user." ) );
+	QWhatsThis::add( m_typelab, QWhatsThis::textFor( m_type ) );
+	QWhatsThis::add( m_format, i18n(
+				"The format of the option. This determines how the option is formatted "
+				"for inclusion in the global command line. The tag <b>%value</b> can be used "
+				"to represent the user selection. This tag will be replaced at run-time by a "
+				"string representation of the option value." ) );
+	QWhatsThis::add( m_formatlab, QWhatsThis::textFor( m_format ) );
+	QWhatsThis::add( m_default, i18n(
+				"The default value of the option. For non persistent options, nothing is "
+				"added to the command line if the option has that default value. If this "
+				"value does not correspond to the actual default value of the underlying "
+				"utility, make the option persistent to avoid unwanted effects." ) );
+	QWhatsThis::add( m_defaultlab, QWhatsThis::textFor( m_default ) );
+	QWhatsThis::add( m_persistent, i18n(
+				"Make the option persistent. A persistent option is always written to the "
+				"command line, whatever its value. This is useful when the chosen default "
+				"value does not match with the actual default value of the underlying utility." ) );
+	QWhatsThis::add( m_command, i18n(
+				"The full command line to execute the associated underlying utility. This "
+				"command line is based on a mechanism of tags that are replaced at run-time. "
+				"The supported tags are:<ul>"
+				"<li><b>%filterargs</b>: command options</li>"
+				"<li><b>%filterinput</b>: input specification</li>"
+				"<li><b>%filteroutput</b>: output specification</li>"
+				"<li><b>%psu</b>: the page size in upper case</li>"
+				"<li><b>%psl</b>: the page size in lower case</li></ul>" ) );
+	QWhatsThis::add( m_commandlab, QWhatsThis::textFor( m_command ) );
+	QWhatsThis::add( m_inputfile, i18n(
+				"Input specification when the underlying utility reads input data from a file. Use "
+				"the tag <b>%in</b> to represent the input filename." ) );
+	QWhatsThis::add( m_inputfilelab, QWhatsThis::textFor( m_inputfile ) );
+	QWhatsThis::add( m_outputfile, i18n(
+				"Output specification when the underlying utility writes output data to a file. Use "
+				"the tag <b>%out</b> to represent the output filename." ) );
+	QWhatsThis::add( m_outputfilelab, QWhatsThis::textFor( m_outputfile ) );
+	QWhatsThis::add( m_inputpipe, i18n(
+				"Input specification when the underlying utility reads input data from its "
+				"standard input." ) );
+	QWhatsThis::add( m_inputpipelab, QWhatsThis::textFor( m_inputpipe ) );
+	QWhatsThis::add( m_outputpipe, i18n(
+				"Output specification when the underlying utility writes output data to its "
+				"standard output." ) );
+	QWhatsThis::add( m_outputpipelab, QWhatsThis::textFor( m_outputpipe ) );
+	QWhatsThis::add( m_comment, i18n(
+				"A comment about the underlying utility, which can be viewed by the user "
+				"from the interface. This comment string supports basic HTML tags like "
+				"&lt;a&gt;, &lt;b&gt; or &lt;i&gt;." ) );
+	QWhatsThis::add( m_commentlab, QWhatsThis::textFor( m_comment ) );
+
 	resize(660, 200);
 }
 
@@ -374,6 +446,7 @@ void KXmlCommandAdvancedDlg::viewItem(QListViewItem *item)
 	m_values->clear();
 	m_edit1->setText("");
 	m_edit2->setText("");
+	m_persistent->setChecked( false );
 	int	typeId(-1);
 	if (item)
 	{
@@ -428,6 +501,8 @@ void KXmlCommandAdvancedDlg::viewItem(QListViewItem *item)
 			DrBase	*nextOpt = (nextItem && m_opts.contains(nextItem->text(1)) ? m_opts[nextItem->text(1)] : 0);
 			m_up->setEnabled(prevOpt && !(prevOpt->type() < DrBase::String && opt->type() >= DrBase::String));
 			m_down->setEnabled(nextOpt && !(isgroup && nextOpt->type() >= DrBase::String));
+
+			m_persistent->setChecked( opt->get( "persistent" ) == "1" );
 		}
 
 		m_delopt->setEnabled(true);
@@ -551,6 +626,7 @@ void KXmlCommandAdvancedDlg::slotApplyChanges()
 
 		opt->setName((m_name->text().isEmpty() ? generateId(m_opts) : m_name->text()));
 		opt->set("text", m_desc->text());
+		opt->set( "persistent", m_persistent->isChecked() ? "1" : "0" );
 
 		m_opts[opt->name()] = opt;
 	}
@@ -628,7 +704,7 @@ void KXmlCommandAdvancedDlg::removeItem(QListViewItem *item)
 
 void KXmlCommandAdvancedDlg::slotMoveUp()
 {
-	QListViewItem	*item = m_view->currentItem(), *prev(0);
+	QListViewItem	*item = m_view->currentItem(), *prev = 0;
 	if (item && (prev=findPrev(item)))
 	{
 		QListViewItem	*after(0);
@@ -647,7 +723,7 @@ void KXmlCommandAdvancedDlg::slotMoveUp()
 
 void KXmlCommandAdvancedDlg::slotMoveDown()
 {
-	QListViewItem	*item = m_view->currentItem(), *next(0);
+	QListViewItem	*item = m_view->currentItem(), *next = 0;
 	if (item && (next=findNext(item)))
 	{
 		item->moveItem(next);
@@ -767,18 +843,18 @@ KXmlCommandDlg::KXmlCommandDlg(QWidget *parent, const char *name)
 	m_requirements = new KListView(m_gb2);
 	m_requirements->addColumn("");
 	m_requirements->header()->hide();
-	m_addreq = new QPushButton(m_gb2);
-	m_addreq->setPixmap(SmallIcon("filenew"));
-	m_removereq = new QPushButton(m_gb2);
-	m_removereq->setPixmap(SmallIcon("editdelete"));
+	m_addreq = new QToolButton(m_gb2);
+	m_addreq->setIconSet(SmallIconSet("filenew"));
+	m_removereq = new QToolButton(m_gb2);
+	m_removereq->setIconSet(SmallIconSet("editdelete"));
 	QPushButton	*m_edit = new KPushButton(KGuiItem(i18n("&Edit Command..."), "edit"), topmain);
 	m_mimetype = new QComboBox(dummy);
 	m_availablemime = new KListBox(m_gb1);
 	m_selectedmime = new KListBox(m_gb1);
-	m_addmime = new QPushButton(m_gb1);
-	m_addmime->setPixmap(SmallIcon("back"));
-	m_removemime = new QPushButton(m_gb1);
-	m_removemime->setPixmap(SmallIcon("forward"));
+	m_addmime = new QToolButton(m_gb1);
+	m_addmime->setIconSet(QApplication::reverseLayout()? SmallIconSet("forward") : SmallIconSet("back"));
+	m_removemime = new QToolButton(m_gb1);
+	m_removemime->setIconSet(QApplication::reverseLayout()? SmallIconSet("back" ) : SmallIconSet("forward"));
 	m_gb2->setMinimumWidth(380);
 	m_gb1->setMinimumHeight(180);
 	m_requirements->setMaximumHeight(80);
