@@ -14,8 +14,8 @@
  *
  *  You should have received a copy of the GNU Library General Public License
  *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- *  Boston, MA 02111-1307, USA.
+ *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ *  Boston, MA 02110-1301, USA.
  */
 
 #include <qbitmap.h>
@@ -105,7 +105,7 @@ KJanusWidget::KJanusWidget( QWidget *parent, const char *name, int face )
       mTreeListResizeMode = QSplitter::KeepSize;
 
       d->mListFrame = new QWidget( d->mSplitter );
-      QVBoxLayout *dummy = new QVBoxLayout( d->mListFrame, 0, 0 );
+      QVBoxLayout *dummy = new QVBoxLayout( d->mListFrame, 0, KDialog::spacingHint() );
       dummy->setAutoAdd( true );
       mTreeList = new KListView( d->mListFrame );
       mTreeList->addColumn( QString::null );
@@ -122,7 +122,6 @@ KJanusWidget::KJanusWidget( QWidget *parent, const char *name, int face )
       QFrame *p = new QFrame( d->mSplitter );
 
       QHBoxLayout *hbox = new QHBoxLayout( p, 0, 0 );
-      hbox->addSpacing( KDialog::marginHint() );
 
       page = new QFrame( p );
       hbox->addWidget( page, 10 );
@@ -867,7 +866,7 @@ void KJanusWidget::addButtonBelowList( const QString & text, QObject * recv, con
 {
   if( ( mFace == TreeList || mFace == IconList ) && d->mListFrame )
   {
-    QPushButton * button = new QPushButton( text, d->mListFrame );
+    QPushButton * button = new QPushButton( text, d->mListFrame, "KJanusWidget::buttonBelowList" );
     connect( button, SIGNAL( clicked() ), recv, slot );
   }
 }
@@ -876,7 +875,7 @@ void KJanusWidget::addButtonBelowList( const KGuiItem & item, QObject * recv, co
 {
   if( ( mFace == TreeList || mFace == IconList ) && d->mListFrame )
   {
-    KPushButton * button = new KPushButton( item, d->mListFrame );
+    KPushButton * button = new KPushButton( item, d->mListFrame, "KJanusWidget::buttonBelowList" );
     connect( button, SIGNAL( clicked() ), recv, slot );
   }
 }
