@@ -13,8 +13,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 /**
@@ -38,7 +38,7 @@ KTabCtl::KTabCtl(QWidget *parent, const char *name)
     connect(tabs, SIGNAL(selected(int)), this, SLOT(showTab(int)));
     tabs->move(2, 1);
 
-    blBorder = TRUE;
+    blBorder = true;
 
 }
 
@@ -319,13 +319,8 @@ void KTabCtl::showTab(int i)
 void KTabCtl::addTab(QWidget *w, const QString& name)
 {
     QTab *t = new QTab();
-#if QT_VERSION < 300
-    t->label = name;
-    t->enabled = TRUE;
-#else
     t->setText( name );
     t->setEnabled( true );
-#endif
     int id = tabs->addTab(t);   /* add the tab itself to the tabbar */
     if (id == (int)pages.size()) {
 	pages.resize(id + 1);
