@@ -973,8 +973,14 @@ void QXEmbed::embed(WId w)
             XWithdrawWindow(qt_xdisplay(), window, qt_xscreen());
             QApplication::flushX();
             // L1711: See L1610
-            while (!wstate_withdrawn(window))
+            for (int i=0; i < 10000; ++i) {
+                if (wstate_withdrawn(window)) {
+                    Window parent = 0;
+                    get_parent(w, &parent);
+                    if (parent == qt_xrootwin()) break;
+                }
                 USLEEP(1000);
+            }
         }
         // L1710: It would be sufficient in principle to reparent
         //        window w into winId(). Everything else happens in L2020.
@@ -1325,13 +1331,14 @@ void QXEmbed::sendSyntheticConfigureNotifyEvent()
     //        See http://lists.kde.org/?l=kfm-devel&m=107090222032378
     QPoint globalPos = mapToGlobal(QPoint(0,0));
     if (window) {
+#if 0
         XConfigureEvent c;
         memset(&c, 0, sizeof(c));
         c.type = ConfigureNotify;
         c.display = qt_xdisplay();
         c.send_event = True;
         c.event = window;
-        c.window = winId();
+        c.window = window;
         c.x = globalPos.x();
         c.y = globalPos.y();
         c.width = width();
@@ -1340,6 +1347,10 @@ void QXEmbed::sendSyntheticConfigureNotifyEvent()
         c.above = None;
         c.override_redirect = 0;
         XSendEvent( qt_xdisplay(), c.event, true, StructureNotifyMask, (XEvent*)&c );
+#endif
+        // Yes, this doesn't make sense at all. See the commit message.
+        XSetWindowBorderWidth( qt_xdisplay(), window, 1 );
+        XSetWindowBorderWidth( qt_xdisplay(), window, 0 );
     }
 }
 
