@@ -178,7 +178,7 @@ QRegion RenderLayer::paintedRegion(RenderLayer* rootLayer)
         convertToLayerCoords(rootLayer,x,y);
         QRect cr(x,y,width(),height());
         if ( s->backgroundImage() || s->backgroundColor().isValid() || s->hasBorder() ||
-             s->scrollsOverflow() || renderer()->isReplaced() ) {
+             renderer()->scrollsOverflow() || renderer()->isReplaced() ) {
             r += cr;
         } else {
             r += renderer()->visibleFlowRegion(x, y);
@@ -539,7 +539,7 @@ void RenderLayer::checkInlineRelOffset(const RenderObject* o, int& x, int& y)
 
 void RenderLayer::scrollToOffset(int x, int y, bool updateScrollbars, bool repaint)
 {
-    if (renderer()->style()->overflow() != OMARQUEE) {
+    if (renderer()->style()->overflowX() != OMARQUEE) {
         if (x < 0) x = 0;
         if (y < 0) y = 0;
 
@@ -655,15 +655,6 @@ int RenderLayer::horizontalScrollbarHeight()
 
 }
 
-void RenderLayer::moveScrollbarsAside()
-{
-    QScrollView* scrollView = m_object->element()->getDocument()->view();
-  if (m_hBar)
-        scrollView->addChild(m_hBar, 0, -50000);
-    if (m_vBar)
-        scrollView->addChild(m_vBar, 0, -50000);
-}
-
 void RenderLayer::positionScrollbars(const QRect& absBounds)
 {
 #ifdef APPLE_CHANGES
@@ -742,21 +733,29 @@ void RenderLayer::checkScrollbarsAfterLayout()
     bool needHorizontalBar = rightPos > width();
     bool needVerticalBar = bottomPos > height();
 
-    bool haveHorizontalBar = m_hBar;
-    bool haveVerticalBar = m_vBar;
+    bool haveHorizontalBar = m_hBar && m_hBar->isEnabled();
+    bool haveVerticalBar = m_vBar && m_vBar->isEnabled();
 
     // overflow:scroll should just enable/disable.
-    if (m_object->style()->overflow() == OSCROLL) {
+    if (m_object->style()->overflowX() == OSCROLL)
         m_hBar->setEnabled(needHorizontalBar);
+    if (m_object->style()->overflowY() == OSCROLL)
         m_vBar->setEnabled(needVerticalBar);
-    }
 
     // overflow:auto may need to lay out again if scrollbars got added/removed.
-    bool scrollbarsChanged = (m_object->style()->overflow() == OAUTO) &&
-        (haveHorizontalBar != needHorizontalBar || haveVerticalBar != needVerticalBar);
+    bool scrollbarsChanged = (m_object->style()->overflowX() == OAUTO && haveHorizontalBar != needHorizontalBar)
+                          || (m_object->style()->overflowY() == OAUTO && haveVerticalBar != needVerticalBar);
     if (scrollbarsChanged) {
-        showScrollbar(Qt::Horizontal, needHorizontalBar);
-        showScrollbar(Qt::Vertical, needVerticalBar);
+        if (m_object->style()->overflowX() == OAUTO) {
+            showScrollbar(Qt::Horizontal, needHorizontalBar);
+            if (m_hBar) 
+                m_hBar->setEnabled(true);
+        }
+        if (m_object->style()->overflowY() == OAUTO) {
+            showScrollbar(Qt::Vertical, needVerticalBar);
+            if (m_vBar)
+                m_vBar->setEnabled(true);
+        }
 
         m_object->setNeedsLayout(true);
 	if (m_object->isRenderBlock())
@@ -1519,7 +1518,7 @@ void RenderLayer::styleChanged()
             sc->dirtyZOrderLists();
     }
 
-    if (m_object->style()->overflow() == OMARQUEE && m_object->style()->marqueeBehavior() != MNONE) {
+    if (m_object->style()->overflowX() == OMARQUEE && m_object->style()->marqueeBehavior() != MNONE) {
         if (!m_marquee)
             m_marquee = new Marquee(this);
         m_marquee->updateMarqueeStyle();
