@@ -39,6 +39,9 @@ class QFontMetrics;
 // Define a constant for soft hyphen's unicode value.
 #define SOFT_HYPHEN 173
 
+const int cNoTruncation = -1;
+const int cFullTruncation = -2;
+
 namespace khtml
 {
     class RenderText;
@@ -50,12 +53,15 @@ public:
     InlineTextBox(RenderObject *obj)
     	:InlineBox(obj),
     	// ### necessary as some codepaths (<br>) do *not* initialize these (LS)
-    	m_start(0), m_len(0), m_reversed(false), m_toAdd(0)
+    	m_start(0), m_len(0), m_truncation(cNoTruncation), m_reversed(false), m_toAdd(0)
     {
     }
 
     void detach(RenderArena* renderArena);
 
+    virtual void clearTruncation() { m_truncation = cNoTruncation; }
+    virtual int placeEllipsisBox(bool ltr, int blockEdge, int ellipsisWidth, bool& foundBox);
+
     // Overloaded new operator.  Derived classes must override operator new
     // in order to allocate out of the RenderArena.
     void* operator new(size_t sz, RenderArena* renderArena) throw();
@@ -73,9 +79,13 @@ public:
 
     virtual bool isInlineTextBox() const { return true; }
 
+    void paint(RenderObject::PaintInfo& i, int tx, int ty);
     void paintDecoration(QPainter *pt, const Font *f, int _tx, int _ty, int decoration);
     void paintShadow(QPainter *pt, const Font* f, int _tx, int _ty, const ShadowData *shadow );
     void paintSelection(const Font *f, RenderText *text, QPainter *p, RenderStyle* style, int tx, int ty, int startPos, int endPos, int deco);
+    
+    void selectionStartEnd(int& sPos, int& ePos);
+    RenderObject::SelectionState selectionState();
 
     // Return before, after (offset set to max), or inside the text, at @p offset
     FindSelectionResult checkSelectionPoint(int _x, int _y, int _tx, int _ty, const Font *f, RenderText *text, int & offset, short lineheight);
@@ -119,6 +129,10 @@ public:
     int m_start;
     unsigned short m_len;
 
+    int m_truncation; // Where to truncate when text overflow is applied.
+                      // We use special constants to denote no truncation (the whole run paints)
+                      // and full truncation (nothing paints at all).
+
     bool m_reversed : 1;
     unsigned m_toAdd : 14; // for justified text
 private:
@@ -233,7 +247,7 @@ public:
     virtual short marginLeft() const { return style()->marginLeft().minWidth(0); }
     virtual short marginRight() const { return style()->marginRight().minWidth(0); }
 
-    virtual void repaint(bool immediate=false);
+    virtual void repaint(Priority p=NormalPriority);
 
     bool hasBreakableChar() const { return m_hasBreakableChar; }
     const QFontMetrics &metrics(bool firstLine) const;
