@@ -29,7 +29,7 @@
 
 using namespace DOM;
 
-EntityImpl::EntityImpl(DocumentPtr *doc) : NodeBaseImpl(doc)
+EntityImpl::EntityImpl(DocumentImpl *doc) : NodeBaseImpl(doc)
 {
     m_publicId = 0;
     m_systemId = 0;
@@ -37,7 +37,7 @@ EntityImpl::EntityImpl(DocumentPtr *doc) : NodeBaseImpl(doc)
     m_name = 0;
 }
 
-EntityImpl::EntityImpl(DocumentPtr *doc, DOMString _name) : NodeBaseImpl(doc)
+EntityImpl::EntityImpl(DocumentImpl *doc, DOMString _name) : NodeBaseImpl(doc)
 {
     m_publicId = 0;
     m_systemId = 0;
@@ -47,7 +47,7 @@ EntityImpl::EntityImpl(DocumentPtr *doc, DOMString _name) : NodeBaseImpl(doc)
         m_name->ref();
 }
 
-EntityImpl::EntityImpl(DocumentPtr *doc, DOMString _publicId, DOMString _systemId, DOMString _notationName) : NodeBaseImpl(doc)
+EntityImpl::EntityImpl(DocumentImpl *doc, DOMString _publicId, DOMString _systemId, DOMString _notationName) : NodeBaseImpl(doc)
 {
     m_publicId = _publicId.implementation();
     if (m_publicId)
@@ -156,12 +156,12 @@ DOMString EntityImpl::toString() const
 
 // -------------------------------------------------------------------------
 
-EntityReferenceImpl::EntityReferenceImpl(DocumentPtr *doc) : NodeBaseImpl(doc)
+EntityReferenceImpl::EntityReferenceImpl(DocumentImpl *doc) : NodeBaseImpl(doc)
 {
     m_entityName = 0;
 }
 
-EntityReferenceImpl::EntityReferenceImpl(DocumentPtr *doc, DOMStringImpl *_entityName) : NodeBaseImpl(doc)
+EntityReferenceImpl::EntityReferenceImpl(DocumentImpl *doc, DOMStringImpl *_entityName) : NodeBaseImpl(doc)
 {
     m_entityName = _entityName;
     if (m_entityName)
@@ -222,14 +222,14 @@ DOMString EntityReferenceImpl::toString() const
 
 // -------------------------------------------------------------------------
 
-NotationImpl::NotationImpl(DocumentPtr *doc) : NodeBaseImpl(doc)
+NotationImpl::NotationImpl(DocumentImpl *doc) : NodeBaseImpl(doc)
 {
     m_publicId = 0;
     m_systemId = 0;
     m_name = 0;
 }
 
-NotationImpl::NotationImpl(DocumentPtr *doc, DOMString _name, DOMString _publicId, DOMString _systemId) : NodeBaseImpl(doc)
+NotationImpl::NotationImpl(DocumentImpl *doc, DOMString _name, DOMString _publicId, DOMString _systemId) : NodeBaseImpl(doc)
 {
     m_name = _name.implementation();
     if (m_name)
@@ -290,7 +290,7 @@ bool NotationImpl::childTypeAllowed( unsigned short /*type*/ )
 // ### need a way of updating these properly whenever child nodes of the processing instruction
 // change or are added/removed
 
-ProcessingInstructionImpl::ProcessingInstructionImpl(DocumentPtr *doc) : NodeBaseImpl(doc)
+ProcessingInstructionImpl::ProcessingInstructionImpl(DocumentImpl *doc) : NodeBaseImpl(doc)
 {
     m_target = 0;
     m_data = 0;
@@ -299,7 +299,7 @@ ProcessingInstructionImpl::ProcessingInstructionImpl(DocumentPtr *doc) : NodeBas
     m_cachedSheet = 0;
 }
 
-ProcessingInstructionImpl::ProcessingInstructionImpl(DocumentPtr *doc, DOMString _target, DOMString _data) : NodeBaseImpl(doc)
+ProcessingInstructionImpl::ProcessingInstructionImpl(DocumentImpl *doc, DOMString _target, DOMString _data) : NodeBaseImpl(doc)
 {
     m_target = _target.implementation();
     if (m_target)
@@ -430,12 +430,13 @@ StyleSheetImpl *ProcessingInstructionImpl::sheet() const
     return m_sheet;
 }
 
-void ProcessingInstructionImpl::setStyleSheet(const DOM::DOMString &url, const DOM::DOMString &sheet)
+void ProcessingInstructionImpl::setStyleSheet(const DOM::DOMString &url, const DOM::DOMString &sheet, const DOM::DOMString &charset)
 {
     if (m_sheet)
 	m_sheet->deref();
     m_sheet = new CSSStyleSheetImpl(getDocument(), url);
     m_sheet->ref();
+    m_sheet->setCharset(charset);
     m_sheet->parseString(sheet);
     if (m_cachedSheet)
 	m_cachedSheet->deref(this);
