@@ -71,8 +71,8 @@
 # define SPT_PADCHAR    '\0'    /* pad process title with nulls */
 #endif
 
-#if defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__)
-# if defined(__NetBSD__)
+#if defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__) || defined(__DragonFly__)
+# if defined(__NetBSD__) || defined(__DragonFly__)
 #  undef SPT_TYPE
 #  define SPT_TYPE      SPT_BUILTIN     /* setproctitle is in libc */
 # endif
