@@ -227,6 +227,13 @@ namespace KIO {
 	 * @see setWindow()
          */
         QWidget *window() const;
+        
+        /**
+         * Updates the last user action timestamp to the given time.
+         * See KApplication::updateUserTimestamp() .
+         * @since 3.5.6
+         */
+        void updateUserTimestamp( unsigned long time );
 
         /**
          * Set the parent Job.
@@ -480,6 +487,11 @@ namespace KIO {
          */
         void setProcessedSize(KIO::filesize_t size);
 
+        /**
+         * @internal
+         */
+        unsigned long userTimestamp() const;
+
         /**
          * @internal
          * Some extra storage space for jobs that don't have their own
