@@ -13,8 +13,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 #include "kmimemagic.h"
 #include <kdebug.h>
@@ -1380,6 +1380,7 @@ void process(struct config_rec* conf, const QString & fn)
 	if ((nbytes = read(fd, (char *) buf, HOWMANY)) == -1) {
 		kdError(7018) << "" << fn << " read failed (" << strerror(errno) << ")." << endl;
 		conf->resultBuf = MIME_BINARY_UNREADABLE;
+		(void)close(fd);
 		return;
 	}
         if ((tagbytes = tagmagic(buf, nbytes))) {
@@ -1388,6 +1389,7 @@ void process(struct config_rec* conf, const QString & fn)
 		nbytes = read(fd, (char*)buf, HOWMANY);
 		if (nbytes < 0) {
 			conf->resultBuf = MIME_BINARY_UNREADABLE;
+			(void)close(fd);
 			return;
 		}
         }
@@ -2262,6 +2264,15 @@ refineResult(KMimeMagicResult *r, const QString & _filename)
 			tmp += "src";
 		r->setMimeType(tmp);
 	}
+	else
+	if ( tmp == "application/x-sharedlib" )
+	{
+		if ( _filename.find( ".so" ) == -1 ) 
+		{
+			tmp = "application/x-executable";
+			r->setMimeType( tmp );
+		}
+	}
 }
 
 KMimeMagicResult *
