@@ -14,8 +14,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #ifndef __kmimetyperesolver_h
@@ -31,7 +31,7 @@
  * A baseclass for KMimeTypeResolver, with the interface,
  * KMimeTypeResolverHelper uses.
  */
-class KMimeTypeResolverBase
+class KIO_EXPORT KMimeTypeResolverBase
 {
 public:
     virtual void slotViewportAdjusted() = 0;
@@ -46,7 +46,7 @@ protected:
  * itself. So an object of this class is used to handle signals, slots etc.
  * and forwards them to the KMimeTypeResolver instance.
  */
-class KMimeTypeResolverHelper : public QObject
+class KIO_EXPORT KMimeTypeResolverHelper : public QObject
 {
     Q_OBJECT
 
