@@ -1,5 +1,5 @@
 /*
- * $Id: tcpslavebase.cpp 415455 2005-05-18 16:34:56Z deller $
+ * $Id: tcpslavebase.cpp 529518 2006-04-13 16:36:07Z mueller $
  *
  * Copyright (C) 2000 Alex Zepeda <zipzippy@sonic.net
  * Copyright (C) 2001-2003 George Staikos <staikos@kde.org>
@@ -19,8 +19,8 @@
  *
  * You should have received a copy of the GNU Library General Public License
  * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -44,6 +44,9 @@
 #include <ksslall.h>
 #include <ksslcertdlg.h>
 #include <kmessagebox.h>
+#ifndef Q_WS_WIN //temporary
+#include <kresolver.h>
+#endif
 
 #include <klocale.h>
 #include <dcopclient.h>
@@ -619,6 +622,7 @@ KSSLCertificateHome::KSSLAuthAction aa;
           !pkcs->getCertificate()->x509V3Extensions().certTypeSSLClient())) {
         certs.remove(*it);
       }
+      delete pkcs;
     }
 
     if (certs.isEmpty()) return;  // we had nothing else, and prompt failed
@@ -757,13 +761,26 @@ int TCPSlaveBase::verifyCertificate()
     KSSLCertificate::KSSLValidationList ksvl = pc.validateVerbose(KSSLCertificate::SSLServer);
 
    _IPmatchesCN = d->kssl->peerInfo().certMatchesAddress();
-   if (!_IPmatchesCN && !d->militantSSL) {  // force this if the user wants it
-      if (d->cc->getHostList(pc).contains(ourHost))
-         _IPmatchesCN = true;
+   if (!_IPmatchesCN) {
+#ifndef Q_WS_WIN //temporary
+      KNetwork::KResolverResults res = KNetwork::KResolver::resolve(d->kssl->peerInfo().peerHost(), "80", KNetwork::KResolver::CanonName);
+      if (!res.isEmpty()) {
+         QString old = d->kssl->peerInfo().peerHost();
+         d->kssl->peerInfo().setPeerHost(res[0].canonicalName());
+         _IPmatchesCN = d->kssl->peerInfo().certMatchesAddress();
+         if (!_IPmatchesCN) {
+            d->kssl->peerInfo().setPeerHost(old);
+         }
+      }
+#endif
+      if (!_IPmatchesCN && !d->militantSSL) { // force this if the user wants it
+         if (d->cc->getHostList(pc).contains(ourHost)) {
+            _IPmatchesCN = true;
+         }
+      }
    }
 
-   if (!_IPmatchesCN)
-   {
+   if (!_IPmatchesCN) {
       ksvl << KSSLCertificate::InvalidHost;
    }
 
@@ -782,6 +799,9 @@ int TCPSlaveBase::verifyCertificate()
     setMetaData("ssl_cipher_bits",
                   QString::number(d->kssl->connectionInfo().getCipherBits()));
     setMetaData("ssl_peer_ip", d->ip);
+    if (!d->realHost.isEmpty()) {
+       setMetaData("ssl_proxied", "true");
+    }
     
     QString errorStr;
     for(KSSLCertificate::KSSLValidationList::ConstIterator it = ksvl.begin();
