@@ -54,6 +54,10 @@ private:
   /* verify that deleted got emitted */
   void VERIFY_DELETED (const QString&);
 
+  void touch_file (const QString& file);
+  void remove_file (const QString& file);
+  void rename_file (const QString& from, const QString& to);
+
   QString  m_lastSignal;
   QString m_workingDir;
   KDirWatch* d;
