@@ -14,8 +14,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 
     Recommended reading explaining FTP details and quirks:
       http://cr.yp.to/ftp.html  (by D.J. Bernstein)
@@ -708,15 +708,14 @@ void Ftp::ftpAutoLoginMacro ()
 {
   QString macro = metaData( "autoLoginMacro" );
 
-  if ( !macro.isEmpty() )
-  {
+  if ( macro.isEmpty() )
+    return;
+
     QStringList list = QStringList::split('\n', macro);
 
-    if ( !list.isEmpty() )
-    {
       for(QStringList::Iterator it = list.begin() ; it != list.end() ; ++it )
       {
-        if ( (*it).find("init") == 0 )
+    if ( (*it).startsWith("init") )
         {
           list = QStringList::split( '\\', macro);
           it = list.begin();
@@ -733,8 +732,6 @@ void Ftp::ftpAutoLoginMacro ()
           break;
         }
       }
-    }
-  }
 }
 
 
@@ -1030,10 +1027,13 @@ int Ftp::ftpOpenDataConnection()
       return iErrCodePASV ? iErrCodePASV : iErrCode;
   }
 
-  iErrCode = ftpOpenEPRTDataConnection();
-  if(iErrCode == 0)
-    return 0; // success
-  ftpCloseDataConnection();
+  if( !config()->readBoolEntry("DisableEPRT", false) )
+  {
+    iErrCode = ftpOpenEPRTDataConnection();
+    if(iErrCode == 0)
+      return 0; // success
+    ftpCloseDataConnection();
+  }
 
   // fall back to port mode
   iErrCode = ftpOpenPortDataConnection();
@@ -1893,6 +1893,7 @@ bool Ftp::ftpReadDir(FtpEntry& de)
       int currentMonth = tmptr->tm_mon;
       //kdDebug(7102) << "Current time :" << asctime( tmptr ) << endl;
       // Reset time fields
+      tmptr->tm_isdst = -1; // We do not know anything about day saving time (of any random day of the year)
       tmptr->tm_sec = 0;
       tmptr->tm_min = 0;
       tmptr->tm_hour = 0;
@@ -2053,11 +2054,24 @@ Ftp::StatusCode Ftp::ftpGet(int& iError, int iCopyFile, const KURL& url, KIO::fi
     if(!mimetypeEmitted)
     {
       mimetypeEmitted = true;
-      array.setRawData(buffer, n);
-      KMimeMagicResult * result = KMimeMagic::self()->findBufferFileType(array, url.fileName());
-      array.resetRawData(buffer, n);
-      kdDebug(7102) << "ftpGet: Emitting mimetype " << result->mimeType() << endl;
-      mimeType( result->mimeType() );
+
+      // We need a KMimeType::findByNameAndContent(data,filename)
+      // For now we do: find by extension, and if not found (or extension not reliable)
+      // then find by content.
+      bool accurate = false;
+      KMimeType::Ptr mime = KMimeType::findByURL( url, 0, false, true, &accurate );
+      if ( !mime || mime->name() == KMimeType::defaultMimeType()
+           || !accurate )
+      {
+        array.setRawData(buffer, n);
+        KMimeMagicResult * result = KMimeMagic::self()->findBufferFileType(array, url.fileName());
+        array.resetRawData(buffer, n);
+        if ( result->mimeType() != KMimeType::defaultMimeType() )
+          mime = KMimeType::mimeType( result->mimeType() );
+      }
+
+      kdDebug(7102) << "ftpGet: Emitting mimetype " << mime->name() << endl;
+      mimeType( mime->name() );
       if( m_size != UnknownSize )	// Emit total size AFTER mimetype
         totalSize( m_size );
     }
@@ -2528,8 +2542,13 @@ Ftp::StatusCode Ftp::ftpCopyGet(int& iError, int& iCopyFile, const QString sCopy
   QCString sPart = QFile::encodeName(sCopyFile + ".part");
   bool bResume = false;
   bool bPartExists = (KDE_stat( sPart.data(), &buff ) != -1);
-  bool bMarkPartial = config()->readBoolEntry("MarkPartial", true);
-  if(bMarkPartial && bPartExists && buff.st_size > 0)
+  const bool bMarkPartial = config()->readBoolEntry("MarkPartial", true);
+
+  if(!bMarkPartial)
+  {
+    sPart = QFile::encodeName(sCopyFile);
+  }
+  else if(bPartExists && buff.st_size > 0)
   { // must not be a folder! please fix a similar bug in kio_file!!
     if(S_ISDIR(buff.st_mode))
     {
