@@ -15,7 +15,7 @@
  *
  *  You should have received a copy of the GNU Lesser General Public
  *  License along with this library; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
 
@@ -120,7 +120,7 @@ namespace KJS {
   double parseDate(const UString &u);
   double KRFCDate_parseDate(const UString &_date);
   double timeClip(double t);
-  double makeTime(struct tm *t, int milli, bool utc);
+  double makeTime(struct tm *t, double milli, bool utc);
 
 } // namespace
 
