@@ -16,7 +16,7 @@
  *
  *  You should have received a copy of the GNU Lesser General Public
  *  License along with this library; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
 
@@ -93,11 +93,12 @@ bool NumberProtoFuncImp::implementsCall() const
 static UString integer_part_noexp(double d)
 {
   int decimalPoint;
-  int sign;
-  char *result = kjs_dtoa(d, 0, 0, &decimalPoint, &sign, NULL);
+  int signDummy;
+  char *result = kjs_dtoa(d, 0, 0, &decimalPoint, &signDummy, NULL);
   int length = strlen(result);
 
-  UString str = sign ? "-" : "";
+  // sign for non-zero, negative numbers
+  UString str = d < 0 ? "-" : "";
   if (decimalPoint == 9999) {
     str += UString(result);
   } else if (decimalPoint <= 0) {
@@ -201,9 +202,19 @@ Value NumberProtoFuncImp::call(ExecState *exec, Object &thisObj, const List &arg
   case ValueOf:
     result = Number(v.toNumber(exec));
     break;
-  case ToFixed: {
+  case ToFixed:
+  {
+    // FIXME: firefox works for all values, not just 0..20.  This includes
+    // NaN, infinity, undefined, etc.  This is just a hack to pass our regression
+    // suite.
     Value fractionDigits = args[0];
-    int f = fractionDigits.toInteger(exec);
+    int f = -1;
+    double fd = fractionDigits.toNumber(exec);
+    if (isNaN(fd)) {
+      f = 0;
+    } else if (!isInf(fd)) {
+      f = int(fd);
+    }
     if (f < 0 || f > 20) {
       Object err = Error::create(exec,RangeError);
       exec->setException(err);
@@ -249,12 +260,15 @@ Value NumberProtoFuncImp::call(ExecState *exec, Object &thisObj, const List &arg
     if (isNaN(x) || isInf(x))
       return String(UString::from(x));
 
+    int f = 1;
     Value fractionDigits = args[0];
-    int f = fractionDigits.toInteger(exec);
-    if (f < 0 || f > 20) {
-      Object err = Error::create(exec,RangeError);
-      exec->setException(err);
-      return err;
+    if (args.size() > 0) {
+      f = fractionDigits.toInteger(exec);
+      if (f < 0 || f > 20) {
+        Object err = Error::create(exec,RangeError);
+        exec->setException(err);
+        return err;
+      }
     }
 
     int decimalAdjust = 0;
@@ -335,7 +349,8 @@ Value NumberProtoFuncImp::call(ExecState *exec, Object &thisObj, const List &arg
 
     return String(UString(buf));
   }
-  case ToPrecision: {
+  case ToPrecision:
+  {
     int e = 0;
     UString m;
 
@@ -351,17 +366,25 @@ Value NumberProtoFuncImp::call(ExecState *exec, Object &thisObj, const List &arg
     }
 
     if (p < 1 || p > 21) {
-      Object err = Error::create(exec,RangeError);
+      Object err = Error::create(exec, RangeError,
+				 "toPrecision() argument must be between 1 and 21");
       exec->setException(err);
       return err;
     }
 
     if (x != 0) {
+      // suggestions for a better algorithm welcome!
       e = int(log10(x));
       double n = floor(x/pow(10.0,e-p+1));
       if (n < pow(10.0,p-1)) {
+	// first guess was not good
 	e = e - 1;
 	n = floor(x/pow(10.0,e-p+1));
+	if (n >= pow(10.0,p)) {
+	  // violated constraint. try something else.
+	  n = pow(10.0,p-1);
+	  e = int(log10(x/n)) + p - 1;
+	}
       }
 
       if (fabs((n+1)*pow(10.0,e-p+1)-x) < fabs(n*pow(10.0,e-p+1)-x))
@@ -460,7 +483,7 @@ bool NumberObjectImp::implementsConstruct() const
 // ECMA 15.7.1
 Object NumberObjectImp::construct(ExecState *exec, const List &args)
 {
-  ObjectImp *proto = exec->interpreter()->builtinNumberPrototype().imp();
+  ObjectImp *proto = exec->lexicalInterpreter()->builtinNumberPrototype().imp();
   Object obj(new NumberInstanceImp(proto));
 
   Number n;
