@@ -16,8 +16,8 @@
  
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
  
     Send comments and bug fixes to Antonio Larrosa <larrosa@kde.org>
  
@@ -27,6 +27,8 @@
 
 #ifdef __cplusplus
 
+#include <kdelibs_export.h>
+
 /**
  * Simple API covering most of the uses of libkmid.
  *
@@ -51,7 +53,7 @@
  * @version 0.9.5 17/01/2000
  * @author Antonio Larrosa Jimenez <larrosa@kde.org> 
  */
-class KMidSimpleAPI 
+class KMID_EXPORT KMidSimpleAPI 
 {
   private:
     class KMidSimpleAPIPrivate;
@@ -181,22 +183,24 @@ class KMidSimpleAPI
 
 extern "C" {
 
+#else
+#define KMID_EXPORT
 #endif
 
  
-  int    kMidInit(void);
-  int    kMidLoad(const char *filename);
-  int    kMidPlay(void);
-  int    kMidStop(void);
-  void   kMidDestruct(void);
-  int    kMidIsPlaying(void);
-  int    kMidDevices(void);
-  const char * kMidName(int i);
-  const char * kMidType(int i);
-  void   kMidSetDevice(int i);
-  void   kMidSetMidiMapper(const char *mapfilename);
-  const char * kMidVersion(void);
-  const char * kMidCopyright(void);
+KMID_EXPORT  int    kMidInit(void);
+KMID_EXPORT  int    kMidLoad(const char *filename);
+KMID_EXPORT  int    kMidPlay(void);
+KMID_EXPORT  int    kMidStop(void);
+KMID_EXPORT  void   kMidDestruct(void);
+KMID_EXPORT  int    kMidIsPlaying(void);
+KMID_EXPORT  int    kMidDevices(void);
+KMID_EXPORT  const char * kMidName(int i);
+KMID_EXPORT  const char * kMidType(int i);
+KMID_EXPORT  void   kMidSetDevice(int i);
+KMID_EXPORT  void   kMidSetMidiMapper(const char *mapfilename);
+KMID_EXPORT  const char * kMidVersion(void);
+KMID_EXPORT  const char * kMidCopyright(void);
 
 
 
